#!/usr/bin/env python3
# @Author: carlosgilgonzalez
# @Date:   2019-07-11T23:33:30+01:00
# @Last modified by:   carlosgilgonzalez
# @Last modified time: 2019-07-12T02:50:43+01:00
name = 'upydev'
# include upydev/upydev_.config
from .websocket_helper import *
